package com.lantone.external.facade;

import com.google.common.collect.Lists;
import com.lantone.common.util.ListUtil;
import com.lantone.common.util.StringUtil;
import com.lantone.external.dto.DataBalanceDTO;
import com.lantone.external.dto.RecDTO;
import com.lantone.external.entity.VLtMedicalRecord;
import com.lantone.external.vo.DataViewVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

@Component
@Slf4j
public class DataBalanceFacade {

    @Autowired
    private VLtBehospitalInfoFacade vLtBehospitalInfoFacade;

    @Autowired
    private VLtHomePageFacade vLtHomePageFacade;

    @Autowired
    private VLtMedicalRecordFacade vLtMedicalRecordFacade;

    public List<DataBalanceDTO> balanceData(DataViewVO dataViewVO){
        try{
            List<DataBalanceDTO> dtoList= Lists.newLinkedList();
            List<String> beHospitalCodeList=vLtBehospitalInfoFacade.getTimeSoltData(dataViewVO);
            if(ListUtil.isNotEmpty(beHospitalCodeList)){
                //获取病案首页数据
                Map<String,String> homePageMap=vLtHomePageFacade.getTimeSoltData(beHospitalCodeList);

                Map<String,List<VLtMedicalRecord>> recMap=vLtMedicalRecordFacade.getTimeSoltData(beHospitalCodeList);
                beHospitalCodeList.stream().forEach(s->{
                    DataBalanceDTO dto=new DataBalanceDTO();
                    dto.setBehospitalCode(s);
                    //拼接病案序号
                    if(StringUtil.isNotEmpty(homePageMap.get(s))){
                        dto.setHomePageId(homePageMap.get(s));
                    }

                    //拼接文书序号
                    if(ListUtil.isNotEmpty(recMap.get(s))){
                        List<RecDTO> recDTOList=Lists.newLinkedList();
                        recMap.get(s).stream().forEach(i->{
                            RecDTO recdto=new RecDTO();
                            recdto.setRecId(i.getRecId());
                            recdto.setRecTitle(i.getRecTitle());

                            recDTOList.add(recdto);
                        });
                        dto.setRecList(recDTOList);
                    }
                    dtoList.add(dto);
                });
            }
            return dtoList;
        }catch (Exception e){
            log.error("数据比对-获取某个入院时间段内的病历数：："+e.getMessage(),new Throwable());
            return null;
        }
    }

}
