package com.lantone.external.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.lantone.common.util.DateUtil;
import com.lantone.common.util.StringUtil;
import com.lantone.external.entity.VLtBehospitalInfo;
import com.lantone.external.service.impl.VLtBehospitalInfoServiceImpl;
import com.lantone.external.vo.DataBalanceVO;
import com.lantone.external.vo.DataViewVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.stream.Collectors;

@Component
@Slf4j
public class VLtBehospitalInfoFacade extends VLtBehospitalInfoServiceImpl {

    /**
     * @Description:根据接口中的参数，进行查询拉取数据到入院登记表
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public List<VLtBehospitalInfo> getBehospitalInfoData(DataViewVO dataViewVO){
        QueryWrapper hisQueryWrapper=queryWrapper(dataViewVO);
        List<VLtBehospitalInfo> list=this.baseMapper.selectList(hisQueryWrapper);
        return list;
    }

    /**
     * @Description:数据比对用，返回his某入院时间段内或指定住院序号的病历序号数量
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public List<String> getTimeSoltData(DataViewVO dataViewVO){
        try{
            List<VLtBehospitalInfo> list=this.baseMapper.selectList(queryWrapper(dataViewVO));
            List<String> beHospitalCodeList=list.stream().map(VLtBehospitalInfo::getBehospitalCode).collect(Collectors.toList());
            return beHospitalCodeList;
        }catch (Exception e){
            log.error("数据比对用，返回his某入院时间段内或指定住院序号的病历序号数量："+e.getMessage(),new Throwable());
            return null;
        }
    }

    /**
     * @Description:拼接查询条件
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public QueryWrapper queryWrapper(DataViewVO dataViewVO){
        //拼接his查询条件
        QueryWrapper queryWrapper=new QueryWrapper<VLtBehospitalInfo>();
        if(dataViewVO.getHospitalId()!=null && dataViewVO.getHospitalId()!=0L){
            queryWrapper.eq("HOSPITAL_ID", Long.hashCode(dataViewVO.getHospitalId()));
        }
        if(StringUtil.isNotEmpty(dataViewVO.getBehospitalCode())){
            queryWrapper.eq("BEHOSPITAL_CODE", dataViewVO.getBehospitalCode());
        }
        if(StringUtil.isNotEmpty(dataViewVO.getStartDate()) && StringUtil.isNotEmpty(dataViewVO.getEndDate())){
            queryWrapper.gt("BEHOSPITAL_DATE", DateUtil.parseDate(dataViewVO.getStartDate()));
            queryWrapper.lt("BEHOSPITAL_DATE",DateUtil.parseDate(dataViewVO.getEndDate()));
        }
        return queryWrapper;
    }

}
