package com.lantone.external.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.lantone.common.util.EntityUtil;
import com.lantone.common.util.ListUtil;
import com.lantone.common.util.StringUtil;
import com.lantone.external.entity.VLtHomePage;
import com.lantone.external.service.impl.VLtHomePageServiceImpl;
import com.lantone.external.vo.DataViewVO;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

@Component
public class VLtHomePageFacade extends VLtHomePageServiceImpl {

    /**
     * @Description:根据接口中的参数，进行查询拉取数据到入院登记表
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public VLtHomePage getHomePageData(DataViewVO dataViewVO){
        try{
            QueryWrapper hisQueryWrapper=queryWrapper(dataViewVO);
            VLtHomePage hisHomePage=this.getOne(hisQueryWrapper);
            return hisHomePage;
        }catch (Exception e){
            log.error(e.getMessage(),new Throwable());
            return null;
        }
    }

    /**
     * @Description:数据比对，根据对应病历序号查找病案号
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public Map<String,String> getTimeSoltData(List<String> beHospitalCodeList){
        QueryWrapper queryWrapper=new QueryWrapper<VLtHomePage>();
        if(ListUtil.isNotEmpty(beHospitalCodeList)){
            queryWrapper.in("BEHOSPITAL_CODE", beHospitalCodeList);
        }
        List<VLtHomePage> list=this.baseMapper.selectList(queryWrapper);
        Map<String,String> map=EntityUtil.makeMapWithKeyValue(list,"behospitalCode","homePageId");
        return map;
    }

    public List<VLtHomePage> getHomePageSupplement(DataViewVO dataViewVO){
        try{
            QueryWrapper hisQueryWrapper=queryWrapper(dataViewVO);
            List<VLtHomePage> list=this.baseMapper.selectList(hisQueryWrapper);
            return list;
        }catch (Exception e){
            log.error(e.getMessage(),new Throwable());
            return null;
        }
    }

    /**
     * @Description:拼接查询条件
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    private QueryWrapper queryWrapper(DataViewVO dataViewVO){
        //拼接HIS查询条件
        QueryWrapper queryWrapper=new QueryWrapper<VLtHomePage>();
        if(StringUtil.isNotEmpty(dataViewVO.getHomePageId())){
            queryWrapper.eq("HOME_PAGE_ID", dataViewVO.getHomePageId());
        }
        if(dataViewVO.getHospitalId()!=null && dataViewVO.getHospitalId()!=0L){
            queryWrapper.eq("HOSPITAL_ID", dataViewVO.getHospitalId());
        }
        if(StringUtil.isNotEmpty(dataViewVO.getBehospitalCode())){
            queryWrapper.eq("BEHOSPITAL_CODE", dataViewVO.getBehospitalCode());
        }
        return queryWrapper;
    }
}
