package com.lantone.external.facade;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.lantone.common.util.EntityUtil;
import com.lantone.common.util.ListUtil;
import com.lantone.common.util.StringUtil;
import com.lantone.external.entity.VLtMedicalRecord;
import com.lantone.external.service.impl.VLtMedicalRecordServiceImpl;
import com.lantone.external.vo.DataViewVO;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

@Component
public class VLtMedicalRecordFacade extends VLtMedicalRecordServiceImpl {

    /**
     * @Description:根据接口中的参数，进行查询拉取数据到入院登记表
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public VLtMedicalRecord getMedicalRecordData(DataViewVO dataViewVO){
        try{
            QueryWrapper hisQueryWrapper=queryHisWrapper(dataViewVO);
            VLtMedicalRecord hisMedicalRecord=this.getOne(hisQueryWrapper);
            return hisMedicalRecord;
        }catch (Exception e){
            log.error(e.getMessage());
            return null;
        }
    }

    /**
     * @Description:数据比对，根据对应病历序号查找文书序号
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public Map<String,List<VLtMedicalRecord>> getTimeSoltData(List<String> beHospitalCodeList){
        QueryWrapper queryWrapper=new QueryWrapper<VLtMedicalRecord>();
        if(ListUtil.isNotEmpty(beHospitalCodeList)){
            queryWrapper.in("BEHOSPITAL_CODE", beHospitalCodeList);
        }
        List<VLtMedicalRecord> list=this.baseMapper.selectList(queryWrapper);
        Map<String,List<VLtMedicalRecord>> map= EntityUtil.makeEntityListMap(list,"behospitalCode");
        return map;
    }

    /**
     * @Description:根据接口中的参数，进行查询拉取数据到入院登记表
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public List<VLtMedicalRecord> getMedicalRecordSupplement(DataViewVO dataViewVO){
        try{
            QueryWrapper hisQueryWrapper=queryHisWrapper(dataViewVO);
            List<VLtMedicalRecord> hisMedicalRecordList=this.baseMapper.selectList(hisQueryWrapper);
            return hisMedicalRecordList;
        }catch (Exception e){
            log.error(e.getMessage());
            return null;
        }
    }

    /**
     * @Description:拼接查询条件
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    private QueryWrapper queryHisWrapper(DataViewVO dataViewVO){
        //拼接HIS查询条件
        QueryWrapper queryWrapper=new QueryWrapper<VLtMedicalRecord>();
        if(StringUtil.isNotEmpty(dataViewVO.getRecId())){
            queryWrapper.eq("REC_ID", dataViewVO.getRecId());
        }
        if(dataViewVO.getHospitalId()!=null && dataViewVO.getHospitalId()!=0L){
            queryWrapper.eq("HOSPITAL_ID", dataViewVO.getHospitalId());
        }
        if(StringUtil.isNotEmpty(dataViewVO.getBehospitalCode())){
            queryWrapper.eq("BEHOSPITAL_CODE", dataViewVO.getBehospitalCode());
        }
        return queryWrapper;
    }
}
