package com.lantone.external.facade;

import com.lantone.common.util.ListUtil;
import com.lantone.common.util.StringUtil;
import com.lantone.external.dto.RespDTO;
import com.lantone.external.entity.VLtBehospitalInfo;
import com.lantone.external.vo.DataViewVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.util.List;

@Component
@Slf4j
public class ViewBehospitalInfoFacade{

    @Autowired
    private VLtBehospitalInfoFacade hisBehospitalInfoFacade;

    /**
     * @Description:根据接口中的参数，进行查询拉取数据到入院登记表
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **/
    public RespDTO getBehospitalInfoData(DataViewVO dataViewVO){
        try{
            //判断入参
            if(dataViewVO.getHospitalId()==null && dataViewVO.getHospitalId()==0L){
                return RespDTO.onError("初始医院ID为空！！");
            }else if(StringUtil.isEmpty(dataViewVO.getBehospitalCode())){
                return RespDTO.onError("住院登记病历号为空！！");
            }
            //从his视图中获取数据
            List<VLtBehospitalInfo> list=hisBehospitalInfoFacade.getBehospitalInfoData(dataViewVO);
            if(ListUtil.isNotEmpty(list)){
                list.stream().forEach(s->{
                    /*BehospitalInfo vo = new BehospitalInfo();
                    BeanUtils.copyProperties(s, vo);
                    vo.setHospitalId(Integer.toUnsignedLong(s.getHospitalId()));
                    vo.setQcTypeId(initQcTypeId(vo));
                    BehospitalInfo behospitalInfo = behospitalInfoFacade.getOne(queryWrapper(vo));
                    //获取到对应数据，存到我方数据库中
                    if (behospitalInfo != null) {
                        //更新数据
                        UpdateWrapper updateWrapper = updateWrapper(behospitalInfo);
                        vo.setIsDeleted(IsDeleteEnum.N.getKey());
                        vo.setGmtModified(new Date());
                        behospitalInfoFacade.update(vo, updateWrapper);
                    } else {
                        //新增数据
                        vo.setGmtCreate(new Date());
                        behospitalInfoFacade.save(vo);
                    }*/
                });
                return RespDTO.onSuc("入院登记操作成功！");
            }else{
                return RespDTO.onSuc("入院登记操作取消，未获取到数据！");
            }
        }catch (Exception e){
            log.error(e.getMessage(),new Throwable());
            return RespDTO.onError("入院登记操作失败！");
        }
    }

    /**
     * @Description:拼接查询条件
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     *
    public QueryWrapper queryWrapper(BehospitalInfo behospitalInfo){
        //拼接朗通查询条件
        QueryWrapper queryWrapper=new QueryWrapper<BehospitalInfo>();
        if(behospitalInfo.getHospitalId()!=null && behospitalInfo.getHospitalId()!=0L){
            queryWrapper.eq("hospital_id", behospitalInfo.getHospitalId());
        }
        if(StringUtil.isNotEmpty(behospitalInfo.getBehospitalCode())){
            queryWrapper.eq("behospital_code", behospitalInfo.getBehospitalCode());
        }
        return queryWrapper;
    }

    private UpdateWrapper updateWrapper(BehospitalInfo behospitalInfo){
        UpdateWrapper updateWrapper=new UpdateWrapper<BehospitalInfo>();
        if(behospitalInfo.getHospitalId()!=null && behospitalInfo.getHospitalId()!=0L){
            updateWrapper.eq("hospital_id", behospitalInfo.getHospitalId());
        }
        if(StringUtil.isNotEmpty(behospitalInfo.getBehospitalCode())){
            updateWrapper.eq("behospital_code", behospitalInfo.getBehospitalCode());
        }
        return updateWrapper;
    }

    *//**
     * @Description:his数据补录,根据单个病历号或某个出院时间段内病历数去进去补录
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **//*
    public RespDTO hisDataSupplement(DataViewVO dataViewVO){
        try {
            //从his视图中获取数据
            List<VLtBehospitalInfo> list=hisBehospitalInfoFacade.getBehospitalInfoData(dataViewVO);
            //将所有病历号组成list集合
            List<String> beHospitalCodeList=list.stream().map(VLtBehospitalInfo::getBehospitalCode).collect(Collectors.toList());
            Map<String, Object> invokeParams = new HashMap<>();
            invokeParams.put("beHospitalCodeList", beHospitalCodeList);
            invokeParams.put("beHospitalInfoList", list);
            invokeParams.put("dataViewVO", dataViewVO);
            RespDTO dto= DataFacade.get("viewDataSupplement", invokeParams, RespDTO.class);

            return dto;
        } catch (Exception e) {
            log.error("数据补录异常！！！！"+e.getMessage(),new Throwable());
            return RespDTO.onError("数据补录异常！！！！"+e.getMessage());
        }
    }

    *//**
     * @Description:
     * @Author:liuqq
     * @time: ${DATE} ${TIME}
     **//*
    public RespDTO getBehospitalInfoData(List<VLtBehospitalInfo> VLtBehospitalInfoList){
        try {
            if (ListUtil.isNotEmpty(VLtBehospitalInfoList)) {
                VLtBehospitalInfoList.stream().forEach(s -> {
                    BehospitalInfo vo = new BehospitalInfo();
                    BeanUtils.copyProperties(s, vo);
                    vo.setHospitalId(Integer.toUnsignedLong(s.getHospitalId()));
                    vo.setQcTypeId(initQcTypeId(vo));
                    BehospitalInfo behospitalInfo = behospitalInfoFacade.getOne(queryWrapper(vo));
                    //获取到对应数据，存到我方数据库中
                    if (behospitalInfo != null) {
                        //更新数据
                        UpdateWrapper updateWrapper = updateWrapper(behospitalInfo);
                        vo.setIsDeleted(IsDeleteEnum.N.getKey());
                        vo.setGmtModified(new Date());
                        behospitalInfoFacade.update(vo, updateWrapper);
                    } else {
                        //新增数据
                        vo.setGmtCreate(new Date());
                        behospitalInfoFacade.save(vo);
                    }
                });
                return RespDTO.onSuc("入院登记数据补录完成！");
            }else{
                return RespDTO.onSuc("入院登记数据补录取消，未获取到数据！");
            }
        }catch (Exception e){
            log.error("入院登记数据补录异常！！！！"+e.getMessage(),new Throwable());
            return RespDTO.onError("入院登记数据补录异常！！！"+e.getMessage());
        }
    }

    *//**
     * 初始化QcTypeId
     * @param s
     * @return
     *//*
    private Long initQcTypeId(BehospitalInfo s) {
        Long qcTypeId = Long.valueOf("0");
        try {
            //根据科室查找对应质控类型
            QcType qcTypeList = qcTypeFacade.getOne(new QueryWrapper<QcType>()
                    .eq("beh_dept_id", s.getBehDeptId())
                    .eq("hospital_id", s.getHospitalId())
                    .eq("default_module", 0)
                    .eq("sex",s.getSex())
                    .eq("is_deleted", IsDeleteEnum.N));
            if(qcTypeList == null){
                //无质控类型时，新增后初始化
                QcType qcType = qcTypeFacade.getOne(new QueryWrapper<QcType>()
                        .eq("default_module", 1)
                        .eq("hospital_id", s.getHospitalId())
                        .eq("sex",s.getSex())
                        .eq("is_deleted", IsDeleteEnum.N));
                if(qcType!=null){
                    qcTypeId = qcType.getId();
                }
            }else {
                qcTypeId = qcTypeList.getId();
            }
        }catch (Exception e){
            log.error("住院登记信息qc_type_id初始化异常！！！！"+e.getMessage(),new Throwable());
        }
        return qcTypeId;
    }*/
}
